# kiosk-common

A common library for Intelligent Weighbridge in Python.

## API References

- [kiosk_common.socket](./docs/api/socket.md)

## License

Copyright (C) 2023 Garrett HE <garrett.he@hotmail.com>

The BSD 3-Clause License, see [LICENSE](./LICENSE).
